//
//  AntiColViewController.m
//  Created by koda on 2015/02/20.
//
//

#import "AntiColViewController.h"
#import "Utils.h"
#import <ASRP31N_SDK/ASRP31N_SDK.h>

@interface AntiColViewController ()<UITableViewDataSource, UITableViewDelegate, ASRP31NSDKDelegate>

@property (weak, nonatomic) IBOutlet UITableView *myTableView;
@property (strong,nonatomic) NSArray *modeList;
@property (assign,nonatomic) NSInteger selectedMode;
@property (assign,nonatomic) NSInteger selectedCounet;
@end

@implementation AntiColViewController

//----------------------------------------------
#pragma mark - LifeCycle
//----------------------------------------------
- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    [ASRP31NSDK sharedInstance].delegate = self;
    [[ASRP31NSDK sharedInstance] getAnticollision];
}

-(void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:YES];
    [ASRP31NSDK sharedInstance].delegate = nil;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.modeList = @[@"MODE 0",
                      @"MODE 1",
                      @"MODE 2",
                      @"MODE 3",
                      @"MODE 4",
                      @"MODE 5",
                      @"MODE 6"];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

//----------------------------------------------
#pragma mark - UITableView Delegate
//----------------------------------------------
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return 5;
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (UITableViewCell*)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier forIndexPath:indexPath];
    
    cell.textLabel.text = _modeList[indexPath.row];
    if (_selectedMode == indexPath.row) {
        cell.accessoryType = UITableViewCellAccessoryCheckmark;
    } else {
        cell.accessoryType = UITableViewCellAccessoryNone;
    }
    
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    for (int i = 0; i < _modeList.count; i++) {
        UITableViewCell *cell = [_myTableView cellForRowAtIndexPath:[NSIndexPath indexPathForRow:i inSection:0]];
        
        if (i == indexPath.row) {
            cell.accessoryType = UITableViewCellAccessoryCheckmark;
            _selectedMode = indexPath.row;
        } else {
            cell.accessoryType = UITableViewCellAccessoryNone;
        }
    }
}

//----------------------------------------------
#pragma mark - IBAction
//----------------------------------------------
- (IBAction)done:(id)sender
{
    [[ASRP31NSDK sharedInstance] setAnticollision:_selectedMode];
}

//----------------------------------------------
#pragma mark - ASRP31NSDK Delegate
//----------------------------------------------
- (void)ASRP31N:(ASRP31NSDK *)ASRP31N receivedAnticollison:(uint8_t)param
{
    _selectedMode = param;
    dispatch_async(dispatch_get_main_queue(),^{
        [self.myTableView reloadData];
    });
}

- (void)ASRP31N:(ASRP31NSDK *)ASRP31N receivedDidSetAntiCollision:(uint8_t)statusCode
{
    switch (statusCode) {
        case ASRP31NSDKCommonStatusSuccess:
            [Utils showAlert:@"Success" message:@"Anticollison Mode changed" view:self];
            break;
            
        case ASRP31NSDKCommonStatusFailure:
            [Utils showAlert:@"Fail" message:@"Anticollison Mode changed" view:self];
            break;
        default:
            break;
    }
}

- (void)ASRP31N:(ASRP31NSDK *)ASRP31N changeNetworkState:(ASRP31NSDKNetworkState)state error:(NSError *)error
{
    switch (state) {
            
        case ASRP31NSDKNetworkStateDisconnected:
            [Utils showAlert:@"Fail" message:@"The network connection is lost." view:self];
            break;
            
        case ASRP31NSDKNetworkStateError:
            break;
            
        default:
            break;
    }
}

@end
