#import "OnOffTimeController.h"
#import "Utils.h"

#import <ASRP31N_SDK/ASRP31N_SDK.h>

@interface OnOffTimeController () <ASRP31NSDKDelegate>
{
    int onTime;
    int offTime;
}

@property (weak, nonatomic) IBOutlet UITextField   *tfOnTime;
@property (weak, nonatomic) IBOutlet UITextField   *tfOffTime;

@end

@implementation OnOffTimeController

//----------------------------------------------
#pragma mark - Lifecycle
//----------------------------------------------
- (void)viewDidLoad
{
    [super viewDidLoad];
}

- (void)viewWillAppear:(BOOL)animated
{
    [ASRP31NSDK sharedInstance].delegate = self;
    
    [self performSelector:@selector(onTickGetOnOffTime)  withObject:nil afterDelay:.2f];
    /*20190621  Response Time Out*/
    [Utils showLoadingView:@"Check Settings" timeOut:df_TIMEOUT_DEFAULT];
}

-(void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:YES];
    [ASRP31NSDK sharedInstance].delegate = nil;
}

//----------------------------------------------
#pragma mark - IBAction
//----------------------------------------------
- (IBAction)btnSetOnOffTime:(id)sender
{
    int onTime  =  [_tfOnTime.text intValue];
    int offTime =  [_tfOffTime.text intValue];
    

    //Japan Hopping OFF
    NSError *error = [[ASRP31NSDK sharedInstance] setFHLBTParamRFLevel:-740 //fix value
                                                                   readTime:onTime
                                                                   idleTime:offTime
                                                           carrierSenseTime:50
                                                           frequencyHopping:1    //fix value
                                                           listenBeforeTalk:2    //fix value
                                                             continuousWave:0];  //fix value
    
    if( error ){
        [Utils showAlert:@"Error" message:[[error userInfo] description] view:self];
    }
}

//----------------------------------------------
#pragma mark - Private Method
//----------------------------------------------
- (void)onTickGetOnOffTime
{
    NSError *error = [[ASRP31NSDK sharedInstance] getFHLBTParam];
    if( error ){
        NSLog(@"%@\n code = %ld\n%@", NSStringFromSelector(_cmd), error.code, error.userInfo);
    }
}

//----------------------------------------------
#pragma mark - ASRP31NSDK Delegate
//----------------------------------------------
- (void)ASRP31N:(ASRP31NSDK *)ASRP31N receivedFHLBT:(NSData *)fhlb
{
    /*20190621  Response Time Out*/
    [Utils hiddenLoadingView];
    
    Byte *b = (Byte*) [fhlb bytes];
    int readTime = (b[0] << 8) | b[1];
    int idleTime = (b[2] << 8) | b[3];
    dispatch_async(dispatch_get_main_queue(),^{
        self->_tfOnTime.text  = [NSString stringWithFormat:@"%d",readTime];
        self->_tfOffTime.text = [NSString stringWithFormat:@"%d",idleTime];
    });
}

- (void)ASRP31N:(ASRP31NSDK *)ASRP31N receivedDidSetFHLBT:(ASRP31NSDKCommonStatus)statusCode
{
    switch (statusCode) {
        case ASRP31NSDKCommonStatusSuccess:
            [Utils showAlert:@"Success" message:@"On/Off time changed" view:self];
            break;
        
        case ASRP31NSDKCommonStatusFailure:
            [Utils showAlert:@"Fail" message:@"On/Off time changed" view:self];
            break;
        default:
            break;
    }
}

- (void)ASRP31N:(ASRP31NSDK *)ASRP31N changeNetworkState:(ASRP31NSDKNetworkState)state error:(NSError *)error
{
    switch (state) {
            
        case ASRP31NSDKNetworkStateDisconnected:
            [Utils showAlert:@"Fail" message:@"The network connection is lost." view:self];
            break;
            
        case ASRP31NSDKNetworkStateError:
            break;
            
        default:
            break;
    }
}

@end
